<?php

declare( strict_types=1 );

namespace WPDesk\ShopMagicCart\Admin\CartsMenu;

use ShopMagicVendor\WPDesk\View\Renderer\SimplePhpRenderer;
use ShopMagicVendor\WPDesk\View\Resolver\DirResolver;
use WPDesk\ShopMagic\Automation\AutomationPostType;
use WPDesk\ShopMagicCart\Cart\Cart;
use WPDesk\ShopMagicCart\Cart\CartTable;

/**
 * Single cart view.
 */
final class SingleCart {
	const SLUG = 'shopmagic_single_cart';

	/** @var CartTable */
	private $cart_dao;

	public function __construct( CartTable $cart_dao ) {
		$this->cart_dao = $cart_dao;
	}

	/** @return void */
	public function hooks() {
		add_action(
			'admin_menu',
			function () {
				add_submenu_page(
					'',
					__( 'Cart', 'shopmagic-abandoned-carts' ),
					__( 'Carts', 'shopmagic-abandoned-carts' ),
					'manage_options',
					self::SLUG,
					[ $this, 'render_page_action' ]
				);
			}
		);
	}


	public static function get_url( Cart $cart ): string {
		$params = [
			'page' => self::SLUG,
			'id'   => $cart->get_id(),
		];

		return AutomationPostType::get_url() . '&' . http_build_query( $params );
	}

	/**
	 * @retrun void
	 * @internal
	 */
	public function render_page_action() {
		$id       = isset( $_GET['id'] ) ? absint( $_GET['id'] ) : 0; // phpcs:ignore WordPress.Security.NonceVerification.Recommended
		$cart     = $this->cart_dao->get_by_primary( (string) $id );
		$renderer = ( new SimplePhpRenderer( new DirResolver( __DIR__ . DIRECTORY_SEPARATOR . 'templates' ) ) );
		$renderer->output_render( 'single-cart', [ 'cart' => $cart ] );
	}
}
