<?php

declare( strict_types=1 );

namespace WPDesk\ShopMagicCart\Cart;

use WPDesk\ShopMagic\Customer\CustomerFactory;
use WPDesk\ShopMagic\Database\Abstraction\DAO;
use WPDesk\ShopMagic\Database\Abstraction\DAO\Item;
use WPDesk\ShopMagic\Exception\CannotCreateGuestException;

final class CartFactory implements DAO\ItemFactory {
	const STATUS_NEW       = 'new';
	const STATUS_ACTIVE    = 'active';
	const STATUS_ABANDONED = 'abandoned';
	const STATUS_RECOVERED = 'recovered';
	const STATUS_ORDERED   = 'ordered';

	/** @var CustomerFactory */
	private $customer_factory;

	public function __construct( CustomerFactory $customer_factory ) {
		$this->customer_factory = $customer_factory;
	}

	public function create_null(): Item {
		return apply_filters(
			'shopmagic/carts/create_cart',
			new Cart(
				0,
				self::STATUS_NEW,
				$this->customer_factory->create_null(),
				new \DateTimeImmutable(),
				new \DateTimeImmutable(),
				[],
				[],
				[],
				0,
				0,
				0,
				'',
				get_woocommerce_currency()
			)
		);
	}

	public function create_item( array $data ): Item {
		if ( ! empty( $data['user_id'] ) ) {
			$customer = $this->customer_factory->create_from_user( new \WP_User( $data['user_id'] ) );
		} else {
			try {
				$customer = $this->customer_factory->create_from_guest_id( (int) $data['guest_id'] );
			} catch ( CannotCreateGuestException $e ) {
				$customer = $this->customer_factory->create_null();
			}
		}

		return apply_filters(
			'shopmagic/carts/create_cart',
			new Cart(
				(int) $data['id'],
				$data['status'],
				$customer,
				new \DateTimeImmutable( $data['last_modified'] ),
				new \DateTimeImmutable( $data['created'] ),
				json_decode( $data['items'], true ),
				json_decode( $data['coupons'], true ),
				json_decode( $data['fees'], true ),
				(float) $data['shipping_tax_total'],
				(float) $data['shipping_total'],
				(float) $data['total'],
				$data['token'],
				$data['currency']
			)
		);
	}
}
