<?php
declare( strict_types=1 );

namespace WPDesk\ShopMagicCart\TestData;

use DateTimeImmutable;
use ShopMagicCartVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WPDesk\ShopMagic\Customer\CustomerDTO;
use WPDesk\ShopMagicCart\Cart\Cart;
use WPDesk\ShopMagicCart\Cart\CartTable;

/**
 * Can inject test data for TestDataProvider
 */
final class CartTestData implements Hookable {

	/** @var CartTable */
	private $cart_table;

	public function __construct( CartTable $cart_table ) {
		$this->cart_table = $cart_table;
	}

	/** @return void */
	public function hooks() {
		add_filter( 'shopmagic/core/test_data_provider/domains', [ $this, 'inject_cart_data_domain' ] );
		add_filter( 'shopmagic/core/test_data_provider/data', [ $this, 'inject_cart_data' ] );
	}

	public function inject_cart_data_domain( array $domains ): array {
		$domains[] = Cart::class;

		return $domains;
	}

	public function inject_cart_data( array $data ): array {
		$cart = $this->cart_table->get_all( [], [ 'id' => 'DESC' ], 0, 1 )->current();
		if ( $cart instanceof Cart ) {
			$data[ Cart::class ] = $cart;
		} else {
			$data[ Cart::class ] = $this->get_cart_stub();
		}

		return $data;
	}

	private function get_cart_stub(): Cart {
		return new Cart(
			1,
			'abandoned',
			new CustomerDTO( true, 0, '', '', '', '', '', '' ),
			new DateTimeImmutable(),
			new DateTimeImmutable(),
			[
				[
					'quantity'      => 1,
					'line_subtotal' => 123.3,
					'key'           => 'ade',
					'product_id'    => wc_get_products(
						[
							'limit'  => 1,
							'return' => 'ids',
						]
					)[0],
				],
			],
			[],
			[],
			0,
			0,
			123.3,
			'test-token',
			'USD'
		);
	}
}
